@@ -41,4 +41,8 @@ class ExasolRelation(BaseRelation):
             },
             'type': type,
         })
-        return cls.from_dict(kwargs)
\ No newline at end of file
+        return cls.from_dict(kwargs)
+
+    @staticmethod
+    def add_ephemeral_prefix(name: str):
+        return f'dbt__CTE__{name}'
\ No newline at end of file
